#!python3
# Inkas project
#   for RC paper
# probability distribution type tests for atmospheric data
# version: 1.0
# date: 2021-11-20
# author Jacek Pawlyta (jpawlyta@onet.eu)

from scipy import stats
import pandas as pd
# import numpy as np
import matplotlib.pyplot as plt

alpha = 0.05
fileName = "SH and NH AP Percentages Inka HOUR -600_2021_11_20.xlsx"
path = "data"

sites = ["Machu picchu", "Chamical", "Tiquischullpa"]

print("***********************************")
print("data file: " + fileName)
print("***********************************\n")

for siteName in sites:
    data = pd.read_excel(path + '/' + fileName, sheet_name=siteName)

    print("***********************************")
    print("\t\t SH " + siteName)
    print("***********************************")
    sd = stats.tstd(data['SH (%)'])
    m = stats.tmean(data['SH (%)'])
    minData = stats.tmin(data['SH (%)'])
    maxData = stats.tmax(data['SH (%)'])
    stat, p = stats.shapiro(data['SH (%)'])
    print("Shapiro-Wilk test of normality for SH")
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Gaussian distribution")
    else:
        print("Not Gaussian distribution")
    print("***********************************")

    print("Kolmogorov-Smirnov test of uniformity for SH " + siteName)
    stat, p = stats.kstest(data['SH (%)'], stats.uniform(loc=minData, scale=maxData - minData).cdf)
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Uniform distribution")
    else:
        print("Not uniform distribution")
    print("***********************************\n")

    print("Kolmogorov-Smirnov test of exponential distribution for SH " + siteName)
    stat, p = stats.kstest(data['SH (%)'], stats.expon(scale=31.81).cdf, N=6)
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Exponential distribution")
    else:
        print("Not exponential distribution")
    print("***********************************\n")

    print("***********************************")
    print("\t\t NH  " + siteName)
    print("***********************************")
    sd = stats.tstd(data['NH (%)'])
    m = stats.tmean(data['NH (%)'])
    minData = stats.tmin(data['NH (%)'])
    maxData = stats.tmax(data['NH (%)'])

    stat, p = stats.shapiro(data['NH (%)'])
    print("Shapiro-Wilk test of normality for NH " + siteName)
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Gaussian distribution")
    else:
        print("not Gaussian distribution")
    print("***********************************\n")

    print("Kolmogorov-Smirnov test of uniformity for NH " + siteName)
    sd = stats.tstd(data['NH (%)'])
    m = stats.tmean(data['NH (%)'])
    stat, p = stats.kstest(data['NH (%)'], stats.uniform(loc=minData, scale=maxData - minData).cdf)
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Uniform distribution")
    else:
        print("not uniform distribution")
    print("***********************************\n")

    print("Kolmogorov-Smirnov test of exponential distribution for NH " + siteName)
    stat, p = stats.kstest(data['NH (%)'], stats.expon(scale=31.81).cdf, N=6)
    print("mean = %.3f, standard deviation = = %.3f" % (m, sd))
    print("stat = %.3f, p = %.3f alpha = %.3f\n" % (stat, p, alpha))
    if p > alpha:
        print("Exponential distribution")
    else:
        print("Not exponential distribution")
    print("***********************************\n")

    plt.title("Histogram for NH " + siteName)
    plt.hist(data['NH (%)'], bins=6)

    # plt.title("Histogram for SH " + siteName)
    # plt.hist(data['SH (%)'], bins=6)

    plt.show()
